@@ -1,15 +1,15 @@
 import cv2
 import numpy as np
-import tensorflow as tf
+
 import tensorflow.keras.backend as tfback
 
 from pathlib import Path
 
-from keras.layers import Conv2D, ZeroPadding2D, Activation, Input, concatenate
-from keras.models import Model
-from keras.layers.normalization import BatchNormalization
-from keras.layers.pooling import MaxPooling2D, AveragePooling2D
-from keras.layers.core import Lambda, Flatten, Dense
+from tensorflow.keras.layers import Conv2D, ZeroPadding2D, Activation, Input, concatenate
+from tensorflow.keras.models import Model
+from tensorflow.keras.layers import BatchNormalization
+from tensorflow.keras.layers import MaxPooling2D, AveragePooling2D
+from tensorflow.keras.layers import Lambda, Flatten, Dense
 
 tfback.set_image_data_format('channels_first')
 
@@ -252,4 +252,3 @@ def img_to_encoding(image, model):
     x_train = np.array([input_img])
     embedding = model.predict_on_batch(x_train)
     return embedding
-   
